SessionInfoExt

Trait SessionInfoExt 

pub trait SessionInfoExt: 'static {
    // Required methods
    fn info(&self) -> &StoredSession;
    fn avatar_data(&self) -> AvatarData;

    // Provided methods
    fn user_id(&self) -> &OwnedUserId { ... }
    fn homeserver(&self) -> &Url { ... }
    fn client_id(&self) -> Option<&ClientId> { ... }
    fn uses_oauth_api(&self) -> bool { ... }
    fn device_id(&self) -> &OwnedDeviceId { ... }
    fn session_id(&self) -> &str { ... }
}
Public trait containing implemented methods for everything that derives from SessionInfo.

To override the behavior of these methods, override the corresponding method of SessionInfoImpl.

Required Methods

fn info(&self) -> &StoredSession

The Matrix session’s info.

fn avatar_data(&self) -> AvatarData

The avatar data to represent this session.

Provided Methods

fn user_id(&self) -> &OwnedUserId

The Matrix session’s user ID.

fn homeserver(&self) -> &Url

The Matrix session’s homeserver.

fn client_id(&self) -> Option<&ClientId>

The OAuth 2.0 client ID, if any.

fn uses_oauth_api(&self) -> bool

Whether this session uses the OAuth 2.0 API.

fn device_id(&self) -> &OwnedDeviceId

The Matrix session’s device ID.

fn session_id(&self) -> &str

The local session’s ID.

Implementors